{% extends "vac-templater/vcl/layout.html" %} {% load i18n %} {% load l10n %} {% load media %} {% load vac_templater_base_helpers %} {% load vac_templater_form_helpers %} {% load vac_templater_widget_helpers %} {% load humanize %} {% block title %}{% trans 'VCL' %} > {% trans 'History' %}{% endblock %} {% block sidebar_section %}history{% endblock %} {% block sidebar_content %}

# {% trans 'History' %} {% trans 'Browse past VCL deployments using VAC Templater' %}

{{ form.group|add_class:"form-control" }}
{{ form.branch|add_class:"form-control" }}
{{ form.commit|add_class:"form-control" }}
{{ form.user|add_class:"form-control" }}
{% if form.paginator.current_page.object_list %}

{% for deployment in form.paginator.current_page.object_list %}
{{ deployment.id }} | {{ deployment.group_name }} [{{ deployment.group_oid|slice:"8" }}] {{ deployment.branch_name }} [{{ deployment.branch_oid|slice:"8" }}] | {{ deployment.old_head_oid|slice:"8" }} → {{ deployment.new_head_oid|slice:"8" }} | {% trans 'Deployed' %} {{ deployment.created_at|naturaltime }} {{ deployment.user }} |
{% endfor %}

{% endif %}
{% endblock %}